<?php
/**
 * Main application class
 *
 * @package wp-image-plus
 * @author InstaProduct
 * @link http://insta-product.com/
 */

//
//Include all function files
require_once( IPIMPR_LIB . '/config.php' );
require_once( IPIMPR_LIB . '/setting.php' );
require_once( IPIMPR_APP . '/viewer.php' );
require_once( IPIMPR_APP . '/controller.php' );

if ( ! class_exists( 'IPImpr_App' ))
{
  class IPImpr_App
  {
    //{{ run

    /**
     * Run all functions
     *
     * @return void
     */
    public static function run()
    {
      $hook = sanitize_title( IPIMPR_TITLE );

      //
      //Admin init
      add_action( 'admin_init', array( __CLASS__, 'adminInit' ) );

      //
      //Add media button
      add_action('media_buttons', array( __CLASS__, 'mediaButton' ) );
      //
      //Add media frame
      add_filter( 'the_editor', array( __CLASS__, 'shortcodeEditorFilter' ) );
      add_action( 'admin_footer', array( __CLASS__, 'mediaFrame' ) );

      //
      //Register admin menu
      add_action( 'admin_menu', array( __CLASS__, 'addAdminMenu' ) );

      //
      //Add css
      add_action( 'admin_print_styles', array( __CLASS__, 'adminGlobalStyle' ), 1000 );

      //
      //Add javascript
      add_action( 'admin_print_scripts', array( __CLASS__, 'adminGlobalScript' ), 1000 );

    }

    //}}
    //{{ adminInit

    /**
     * Admin init
     *
     * @return void
     */
    public static function adminInit()
    {
      /**
       * Ajax handler
       **/
      $controller = new IPImpr_Controller();
      $controller->ajax();
    }

    //}}
    //{{ addAdminMenu

    /**
     * Add admin menu
     *
     * @return void
     */
    public static function addAdminMenu()
    {
      add_options_page(
    		IPIMPR_TITLE,
    		IPIMPR_TITLE,
    		'manage_options',
        IPIMPR_PAGENAME . '-setting',
        array( __CLASS__, 'setting' )
    	);
    }

    //}}
    //{{ setting

    /**
     * Add administrator setting page
     *
     * @return void
     */
    public static function setting()
    {
      $viewer = new IPimpr_Viewer();
      $viewer->setting();
    }

    //}}
    //{{ mediaButton

    /**
     * Add media button
     *
     * @return void
     */
    public static function mediaButton()
    {
      ?>
      <button
        class="button ipimpr-media-button"
        id="ipimpr-media-button"
        type="button"
        data-choose="<?php _e( 'Select Image', IPIMPR_SLUG ); ?>">
        <span class="dashicons-before dashicons-format-gallery"></span>
        <?php echo IPIMPR_TITLE; ?>
      </button>
      <?php
    }

    //}}
    //{{ shortcodeEditorFilter

    /**
     * The editor filter
     *
     * @param  string $content
     * @return string
     */
    public static function shortcodeEditorFilter( $content )
    {
      global $ipimpr_useEditor;
      $ipimpr_useEditor = true;
      return $content;
    }

    //}}
    //{{ mediaFrame

    /**
     * Add media frame template
     *
     * @return void
     */
    public static function mediaFrame()
    {
      global $ipimpr_useEditor;

      wp_enqueue_script('wp-color-picker');
      wp_enqueue_style('wp-color-picker');

      if ( $ipimpr_useEditor ) {
        $viewer = new IPImpr_Viewer();
        $viewer->media();
      }
    }

    //}}
    //{{ adminGlobalStyle

    /**
     * Add Css file to all pages
     *
     * @return void
     */
    public static function adminGlobalStyle()
    {
      wp_deregister_style( 'ipimpr-admin-global-style' );
      wp_register_style('ipimpr-admin-global-style', IPIMPR_BASE_URL . 'assets/css/admin-global.min.css', false, null);
      wp_enqueue_style('ipimpr-admin-global-style');
    }

    //}}
    //{{ adminGlobalScript

    /**
     * Add javascript file to all pages
     *
     * @return void
     */
    public static function adminGlobalScript()
    {
      ?>
      <script type="text/javascript">
        var ipimpr_img_url = '<?php echo IPIMPR_BASE_URL . 'assets/img/'; ?>',
          ui_base_image  = '<?php echo IPIMPR_BASE_URL . 'assets/img/'; ?>',
          ui_message     =
          {
            delete_confirm_title: '<?php _e( 'Delete Confirmation', IPIMPR_SLUG ); ?>',
            delete_confirm_info: '<?php _e( 'Are you sure doing this action?', IPIMPR_SLUG ); ?>'
          }
      </script>
      <?php
      //FabricJS
      wp_deregister_script('ipimpr-fabricjs-script');
      wp_enqueue_script(
        'ipimpr-fabricjs-script',
        IPIMPR_BASE_URL . 'assets/js/third_party/fabric.min.js',
        array(),
        1,
        true
      );
      //CamanJS
      wp_deregister_script('ipimpr-camanjs-script');
      wp_enqueue_script(
        'ipimpr-camanjs-script',
        IPIMPR_BASE_URL . 'assets/js/third_party/caman.full.min.js',
        array(),
        1,
        true
      );

      //Global script
      wp_deregister_script('ipimpr-admin-global-script');
      wp_enqueue_script(
        'ipimpr-admin-global-script',
        IPIMPR_BASE_URL . 'assets/js/admin-global.js',
        array( 'jquery' ),
        1,
        true
      );
    }

    //}}
  }
}
